FitsTiler
=========

.. currentmodule:: toasty.fits_tiler

.. autoclass:: FitsTiler
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~FitsTiler.builder
      ~FitsTiler.coll
      ~FitsTiler.force_hipsgen
      ~FitsTiler.force_tan
      ~FitsTiler.out_dir

   .. rubric:: Methods Summary

   .. autosummary::

      ~FitsTiler.should_use_hipsgen
      ~FitsTiler.tile

   .. rubric:: Attributes Documentation

   .. autoattribute:: builder
   .. autoattribute:: coll
   .. autoattribute:: force_hipsgen
   .. autoattribute:: force_tan
   .. autoattribute:: out_dir

   .. rubric:: Methods Documentation

   .. automethod:: should_use_hipsgen
   .. automethod:: tile
